Module error

Module error 

Structs

AppError
ErrorContract
Single source of truth for every public error code, its exit code, and the description published in blotter schema.

Constants

ERROR_CONTRACT

Functions

error_codes
exit_code_for
exit_code_map

Type Aliases

AppResult